@@ -1,4 +1,4 @@
-__version__ = "1.1.0"
+__version__ = "1.1.1"
 
 import hashlib
 from collections import Counter
@@ -150,6 +150,9 @@ class PasswordGenerator:
 
         Returns:
             str: The freshly generated password
+
+        Todo:
+            Allow overriding of each option directly in the :meth:`~passwd.PasswordGenerator.generate` call
         """
         allowed_chars = ""
 
